@@ -33,9 +33,9 @@ export GUILE_LOAD_PATH="$prefix/share/guile/site"
 
 help2man="help2man"
 
-bin1="dotlock.mailutils frm.mailutils from.mailutils mailutils mail.mailutils mailutils-config messages.mailutils mimeview movemail.mailutils popauth readmsg.mailutils sieve"
-#bin1scm="sieve2scm"
-sbin8="comsatd imap4d maidag pop3d"
+bin1="decodemail dotlock.mailutils frm.mailutils from.mailutils mailutils mail.mailutils mailutils-config messages.mailutils mimeview movemail.mailutils popauth putmail readmsg.mailutils sieve"
+#bin1scm="guimb"
+sbin8="comsatd imap4d lmtpd mda pop3d"
 libexec8=""
 
 for program in $bin1; do
